@@ -1,5 +1,3 @@
-from django.conf import settings
-from ...bower import bower_adapter
 from ..base import BaseBowerCommand
 
 
@@ -8,4 +6,4 @@ class Command(BaseBowerCommand):
 
     def handle(self, *args, **options):
         super(Command, self).handle(*args, **options)
-        bower_adapter.install(settings.BOWER_INSTALLED_APPS, *args)
+        self._install(args)
